brtVirus: brtVirus construct brtVirus object

View source: R/class.R

brtVirusR Documentation

brtVirus construct brtVirus object

Description

brtVirus construct brtVirus object

Usage

brtVirus(x, batch)

Arguments

x

a data.frame, with colnames bc describe the sequence of each barcode and counts describe the counts of each bc

batch

which batch the virus is


c57bl/Brt documentation built on May 20, 2022, 8:45 p.m.