Learn R Programming

brt (version 1.3.0)

tpvaltreat: Hypothesis testing using the Student t Distribution with H0: abs(mu) <= delta

Description

Hypothesis testing using the Student t Distribution with H0: abs(mu) <= delta

Usage

tpvaltreat(coefficients, delta, se, df, log = FALSE)

Arguments

coefficients

a vector

delta

a postive cutoff

se

standard error

df

degrees of freedom

log

the probability is in log-scale

Examples

Run this code
# NOT RUN {
x=seq(from=-30, to=30, length.out=100)

data=do.call(
  rbind
  , lapply(
    seq_len(10)
    , function(delta)
      rbind(
        data.frame(x, pval=tpvaltreat(x, delta=delta, se=1, df=3), delta=delta)
        )
    )
  )

ggplot2::qplot(x, pval, data=data, color=as.factor(delta), linetype=as.factor(delta), geom='line')
# }

Run the code above in your browser using DataLab