View source: R/preprocessing.R
| brtSetNoiseBc | R Documentation |
The data is noisy, it is important to identify noise. RV seldom infect non-neuronal cells from neurons, thus the bcs expressing levels of non-neuronal groups reflects the noise level of experiment. By measure the median + threshold * IQR, the threshold of signal can be determined.
brtSetNoiseBc(obj, background = NULL, threshold = 3, signal = "Neurons")
obj |
an brtstarter object, the idents of coldata should contain Neurons and at least one non-neuronal ident. |
background |
a character vector, describe which non-neuronal cluster used to calculate the threshold. Using all non-neuronal groups if none is provided. |
threshold |
a numeric value, default to be 3 |
signal |
a character, describe which ident is signal, default is Neurons |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.