| brtVirus | R Documentation |
brtVirus construct brtVirus object
brtVirus(x, batch)
x |
a data.frame, with colnames bc describe the sequence of each barcode and counts describe the counts of each bc |
batch |
which batch the virus is |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.